/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.test;

import com.jayway.restassured.response.Cookie;
import com.jayway.restassured.response.Response;

import static com.google.common.base.Objects.toStringHelper;
import static org.fest.assertions.Assertions.assertThat;

public class TestUser {
  public static final String JSESSION_ID = "JSESSIONID";
  public static final String REMEMBER_ME = "SPRING_SECURITY_REMEMBER_ME_COOKIE";

  public final String email;
  public final String password;
  public final Cookie sessionCookie;

  public TestUser(String email, String password, boolean rememberMe, Response response) {
    this.email = email;
    this.password = password;
    if (rememberMe) {
      assertThat(response.getCookie(TestUser.REMEMBER_ME)).isNotNull();
      this.sessionCookie = new Cookie.Builder(REMEMBER_ME, response.getCookie(REMEMBER_ME)).build();
    } else {
      assertThat(response.getCookie(TestUser.JSESSION_ID)).isNotNull();
      this.sessionCookie = new Cookie.Builder(JSESSION_ID, response.getCookie(JSESSION_ID)).build();
    }
  }

  @Override
  public String toString() {
    return toStringHelper(this)
      .add("email", email)
      .add("password", password)
      .add("sessionCookie", sessionCookie)
      .toString();
  }
}
